@@ -2,7 +2,7 @@
 # LICENSE:  GPLv3, eead licensing terms at  http://www.fsf.org .
 
 package Pg::Pcurse::Defaults;
-use 5.008008;
+use v5.8;
 our $VERSION = '0.15';
 use warnings;
 use strict;
@@ -178,3 +178,33 @@ our $pg_default =  {
 };
 1;
 __END__
+=head1 NAME
+
+Pg::Pcurse::Defaults  - Configuration defaults for Pg::Pcurse
+
+=head1 SYNOPSIS
+
+  use Pg::Pcurse::Defaults
+
+=head1 DESCRIPTION
+
+Configuration defaultgs for Pg::Pcurse
+
+
+=head1 SEE ALSO
+
+Pg::Pcurse, pcurse(1)
+
+=head1 AUTHOR
+
+Ioannis Tambouras, E<lt>ioannis@cpan.org<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2008 by Ioannis Tambouras
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms of GPLv3
+
+
+=cut
