@@ -1,7 +1,7 @@
 # Copyright (C) 2008 Ioannis Tambouras <ioannis@cpan.org>. All rights reserved.
 # LICENSE:  GPLv3, eead licensing terms at  http://www.fsf.org .
 package Pg::Pcurse::Query0;
-use 5.008008;
+use v5.8;
 use DBIx::Abstract;
 use Carp::Assert;
 use base 'Exporter';
@@ -119,7 +119,7 @@ sub misc_system_wide {
         my $dh = dbconnect ( $o, form_dsn($o,'')) or return;
 
 	my $h0 = $dh->select_one_to_hashref(
-		'pg_postmaster_start_time()::timestamp(0) as start' );
+		'pg_postmaster_start_time()::timestamp(0) AS start' );
 
 	my $h1 = $dh->select_one_to_hashref( 'txid_current()' );
 
@@ -144,24 +144,24 @@ sub object_totals {
 
 	if ($mode eq 'all') {
 		($st = $dh->{dbh}->prepare(<<""))->execute()   
-			 select relkind, count(2) from pg_class group by 1
+			 SELECT relkind, count(2) FROM pg_class GROUP BY 1
 
 	}elsif( $mode eq 'noshared-nosystem') {
 		($st=$dh->{dbh}->prepare(<<""))->execute();   
-		      select relkind, count(2) 
-                      from     pg_class     c 
-                          join pg_namespace n on(n.oid=c.relnamespace)
-		      where not relisshared 
+		      SELECT relkind, count(2) 
+                      FROM     pg_class     C 
+                          join pg_namespace N on(N.oid=C.relnamespace)
+		      WHERE not relisshared 
 		            and nspname !~ '^pg_'
 		            and nspname !~ '^information_schema'
-		      group by 1
+		      GROUP BY 1
 
 	}else{
 	 	my $shared = $mode eq 'shared' ? 'true' : 'false';
 		($st=$dh->{dbh}->prepare(<<""))->execute( $shared );   
-			 select relkind, count(2) from pg_class 
-			 where relisshared = ?
-                         group by 1
+			 SELECT relkind, count(2) FROM pg_class 
+			 WHERE relisshared = ?
+                         GROUP BY 1
 
 	}
 
@@ -183,4 +183,33 @@ sub oid2name_per_db {
 }
 1;
 __END__
-                     'and', 'relname','!~','^sql_']);
+=head1 NAME
+
+Pg::Pcurse::Query0  - Support SQL queries for Pg::Pcurse
+
+=head1 SYNOPSIS
+
+  use Pg::Pcurse::Query0;
+
+=head1 DESCRIPTION
+
+Support SQL queries for Pg::Pcurse
+
+
+=head1 SEE ALSO
+
+Pg::Pcurse, pcurse(1)
+
+=head1 AUTHOR
+
+Ioannis Tambouras, E<lt>ioannis@cpan.org<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2008 by Ioannis Tambouras
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms of GPLv3
+
+
+=cut
