@@ -1,7 +1,7 @@
 # Copyright (C) 2008 Ioannis Tambouras <ioannis@cpan.org>. All rights reserved.
 # LICENSE:  GPLv3, eead licensing terms at  http://www.fsf.org .
 package Pg::Pcurse::Query1;
-use 5.008008;
+use v5.8;
 use DBIx::Abstract;
 use Carp::Assert;
 use base 'Exporter';
@@ -63,15 +63,15 @@ sub get_proc {
 	my $dh = dbconnect ( $o, form_dsn($o,$database)  ) or return;
 	$schema = $dh->quote($schema);
         my $h = $dh->{dbh}->selectall_arrayref(<<"" );
-	select proname,           lanname,
-	       proisstrict as s,  proretset as set,  provolatile as v,
-	       pronargs as nargs, prorettype::regtype, 
-               p.oid
-	from pg_proc  p
-             join pg_namespace n on (pronamespace=n.oid)
-	     join pg_language  l on (prolang=l.oid)
-	where nspname=$schema
-	order by 1
+	SELECT proname,           lanname,
+	       proisstrict AS s,  proretset AS set,  provolatile AS v,
+	       pronargs AS nargs, prorettype::regtype, 
+               P.oid
+	FROM pg_proc  P
+             join pg_namespace N on (pronamespace=N.oid)
+	     join pg_language  L on (prolang=L.oid)
+	WHERE nspname=$schema
+	ORDER BY 1
 
 	[  map { sprintf '%-25s%-9s%7s%7s%9s%7s%9s%40s', @{$_}[0..7]} 
            @$h ];
@@ -294,13 +294,13 @@ sub schema_trg {
         my $dh = dbconnect ( $o, form_dsn($o,$database)  ) or return;
         $schema = $dh->quote($schema);
         my $h   = $dh->{dbh}->selectall_arrayref(<<"") ;
-		select t.oid, c.relname,  tgname,
-		       tgenabled as enabled
-		from          pg_trigger   t
-			 join pg_class     c  on (c.oid=tgrelid)
-			 join pg_namespace s  on (c.relnamespace=s.oid )
-		where nspname = $schema
-		order by 2 , 3
+		SELECT T.oid, C.relname,  tgname,
+		       tgenabled AS enabled
+		FROM          pg_trigger   T
+			 join pg_class     C  on (C.oid=tgrelid)
+			 join pg_namespace S  on (C.relnamespace=S.oid )
+		WHERE nspname = $schema
+		ORDER BY 2 , 3
 
         [ map { sprintf '%-25s  %-44s %1s %30s', @{$_}[1..3,0] }
 	      @$h 
@@ -318,9 +318,9 @@ sub get_users {
         my $dh = dbconnect ( $o, form_dsn($o,$database)  ) or return;
         my $h   = $dh->{dbh}->selectall_arrayref(<<"") ;
 	select usename,
-		case when(usesuper)  then 'super' else ''  end as superuser,
-		case when(usecatupd) then 'catupd' else '' end as catupd,
-		case when(usecreatedb) then 'createdb' else '' end as createdb
+		case when(usesuper)  then 'super' else ''  end AS superuser,
+		case when(usecatupd) then 'catupd' else '' end AS catupd,
+		case when(usecreatedb) then 'createdb' else '' end AS createdb
 	from pg_user
 	order by 2 desc,1
 
@@ -334,7 +334,7 @@ sub vacuum_per_table {
 	my ($o, $database , $schema, $table) = @_;
 	my $dh = dbconnect ( $o, form_dsn($o, $database ) ) or return;
         my $h  = $dh->select_one_to_hashref(
-                      [ 'vacrelid::regclass::text as name' , qw(
+                      [ 'vacrelid::regclass::text AS name' , qw(
                         enabled  vac_base_thresh  vac_scale_factor 
 			anl_base_thresh   anl_scale_factor   vac_cost_delay  
 			vac_cost_limit   freeze_min_age   freeze_max_age
@@ -380,14 +380,14 @@ sub over_dbs {
 	my $dh = dbconnect ( $o, form_dsn($o, $database ) ) or return;
         my $h  = $dh->select_one_to_hashref( {
                       fields=> ['pg_database.datname',
-			        'pg_get_userbyid(datdba) as dba',
-				'pg_encoding_to_char(encoding) as encoding',
+			        'pg_get_userbyid(datdba) AS dba',
+				'pg_encoding_to_char(encoding) AS encoding',
 			         qw( datistemplate  datallowconn  datconnlimit 
 			             datlastsysoid  datfrozenxid  dattablespace
                                      datconfig      datacl        oid
                                  ), 'age(datfrozenxid)',
-	      'pg_database_size(pg_database.datname) as bytes',
-	      'pg_size_pretty( pg_database_size(pg_database.datname)) as size',
+	      'pg_database_size(pg_database.datname) AS bytes',
+	      'pg_size_pretty( pg_database_size(pg_database.datname)) AS size',
                                 ],
                       table => 'pg_database,pg_stat_database',
 		      join  => 'pg_database.datname=pg_stat_database.datname',
@@ -427,11 +427,11 @@ sub table_stat {
                 reltriggers   relukeys        relfkeys        relrefs       
                 relhasoids    relhaspkey      relhasrules     relhassubclass
                 relname       relfilenode     relpages        relacl  reloptions
-                     ), 'pg_get_userbyid(relowner) as owner',
-			'pg_class.oid as coid',
+                     ), 'pg_get_userbyid(relowner) AS owner',
+			'pg_class.oid              AS coid',
 			'age(relfrozenxid)',
-	                'pg_size_pretty(pg_relation_size(pg_class.oid)) as rsi',
-	     'pg_size_pretty( pg_total_relation_size(pg_class.oid)) as trsize',
+	                'pg_size_pretty(pg_relation_size(pg_class.oid)) AS rsi',
+	     'pg_size_pretty( pg_total_relation_size(pg_class.oid)) AS trsize',
                       ],
 	   table  => 'pg_class,pg_namespace',
 	   join   => 'pg_class.relnamespace=pg_namespace.oid',
@@ -524,7 +524,7 @@ sub buffercache_summary {
         my $dh = dbconnect ( $o, form_dsn($o, $database ) ) or return;
 
         my $h = $dh->select_one_to_hashref(<<"");
-           user in (select rolname from pg_roles where rolsuper) as super
+           user in (select rolname from pg_roles where rolsuper) AS super
 
         return [ q(Must be in a "super" role to view buffer data.) ]
                      unless $h->{super};
@@ -535,11 +535,11 @@ sub buffercache_summary {
         $dh = dbconnect ( $o, form_dsn($o, $db_of_func ) ) or return;
 
 	$h = $dh->select_one_to_hashref(
-	[ '(select count(*) from pg_buffercache) as total',
-'(select count(*) from pg_buffercache where relfilenode is not null) as taken',
-'(select count(*) from pg_buffercache where relfilenode is null) as empty',
+	[ '(select count(*) from pg_buffercache) AS total',
+'(select count(*) from pg_buffercache where relfilenode is not null) AS taken',
+'(select count(*) from pg_buffercache where relfilenode is null) AS empty',
 '(select count(*) from pg_buffercache where relfilenode is not null
-and usagecount>1) as "usage>1"',
+and usagecount>1) AS "usage>1"',
 ] ); 
 
 	[ sprintf( '%-10s : %8d', 'total'  , $h->{total}),
@@ -558,12 +558,12 @@ sub index3 {
 	my $dh = dbconnect ( $o, form_dsn($o, $database ) ) or return;
 	$schema = $dh->quote( $schema );
 	my $h = $dh->{dbh}->selectall_arrayref( <<"");
-		select indexrelname, reltuples, relpages,  idx_scan,
+		SELECT indexrelname, reltuples, relpages,  idx_scan,
 		       idx_tup_fetch,   indexrelid
-		 from        pg_stat_user_indexes s
-			join pg_class c on ( c.relname = s.indexrelname )
-		 where schemaname = $schema
-		 order by 1
+		 FROM        pg_stat_user_indexes S
+			join pg_class C on ( C.relname = S.indexrelname )
+		 WHERE schemaname = $schema
+		 ORDER by 1
 
         [ map { sprintf '%-30s  %10s  %5s %8s %8s %90s', @{$_}[0..5] }
 	      @$h ]
@@ -584,9 +584,9 @@ sub get_index {
                        indisclustered  indisvalid  indcheckxmin  indisready 
                        indkey indclass indoption   indexprs      indpred
 		       relpages        reltuples ),
-		     'pg_get_userbyid(relowner) as owner',
-		     'pg_get_indexdef(indexrelid) as def',
-		     'pg_size_pretty(pg_relation_size(indexrelid)) as siz',
+		     'pg_get_userbyid(relowner) AS owner',
+		     'pg_get_indexdef(indexrelid) AS def',
+		     'pg_size_pretty(pg_relation_size(indexrelid)) AS siz',
 	         ],
 		table=> 'pg_index, pg_class',
 		join => 'pg_index.indexrelid=pg_class.oid',
@@ -630,8 +630,8 @@ sub over_dbs3 {
 	my $dh = dbconnect ( $o, form_dsn($o, $database ) ) or return;
         my $h  = $dh->select_one_to_hashref( {
                       fields=> ['pg_database.datname',
-			        'pg_get_userbyid(datdba) as dba',
-				'pg_encoding_to_char(encoding) as encoding',
+			        'pg_get_userbyid(datdba) AS dba',
+				'pg_encoding_to_char(encoding) AS encoding',
 			         qw( datistemplate  datallowconn  datconnlimit 
 			             datlastsysoid  datfrozenxid  dattablespace
                                      datconfig      datacl        blks_read
@@ -639,7 +639,7 @@ sub over_dbs3 {
 				     tup_returned   tup_fetched   tup_inserted
 				     tup_updated    tup_deleted   oid
                                  ), 'age(datfrozenxid)',
-	      'pg_size_pretty( pg_database_size(pg_database.datname)) as size',
+	      'pg_size_pretty( pg_database_size(pg_database.datname)) AS size',
                                 ],
                       table => 'pg_database,pg_stat_database',
 		      join  => 'pg_database.datname=pg_stat_database.datname',
@@ -672,9 +672,9 @@ sub index3b {
 		       [qw( relid         indexrelid    
 			    relname       indexrelname   idx_scan    
 			    idx_tup_read  idx_tup_fetch),
-	                "pg_stat_get_blocks_fetched($oid) as bfetched",
-	                "pg_stat_get_blocks_hit($oid)     as bhit",
-	                "pg_stat_get_numscans($oid)       as nscans",
+	                "pg_stat_get_blocks_fetched($oid) AS bfetched",
+	                "pg_stat_get_blocks_hit($oid)     AS bhit",
+	                "pg_stat_get_numscans($oid)       AS nscans",
                        ],
 			'pg_stat_user_indexes',
 	                [ 'indexrelid', '=', $oid ] );
@@ -709,7 +709,7 @@ sub fsm_settings {
 
         # more results if we can fsm functions are installed, and we are super
         $h = $dh->select_one_to_hashref(<<"");
-           user in (select rolname from pg_roles where rolsuper) as super
+           user in (select rolname from pg_roles where rolsuper) AS super
 
         return $ret1  unless $h;
 	my $db_of_func = search4func( $o, 'pg_freespacemap_pages',
@@ -758,7 +758,7 @@ sub pgbuffercache {
         my $dh = dbconnect ( $o, form_dsn($o, $database ) ) or return;
 
         my $h = $dh->select_one_to_hashref(<<"");
-	   user in (select rolname from pg_roles where rolsuper) as super
+	   user in (select rolname from pg_roles where rolsuper) AS super
 
         return [ q(Must be in a "super" role to view buffer data.) ]
                      unless $h->{super}; 
@@ -770,7 +770,7 @@ sub pgbuffercache {
 	if ($db_of_func eq $database) {
 		goto &not_cached  if $mode =~ /^not_cached$/io;
 		(my $st = $dh->{dbh}->prepare(<<""))->execute;
-		select B.relfilenode::regclass as name, count(1), relpages
+		select B.relfilenode::regclass AS name, count(1), relpages
 		from   pg_buffercache B join pg_class C on (B.relfilenode=C.oid)
 		where  B.relfilenode is not null
 		group  by 1, relpages
@@ -820,3 +820,33 @@ sub not_cached {
 
 1;
 __END__
+=head1 NAME
+
+Pg::Pcurse::Query1  - Support SQL queries for Pg::Pcurse
+
+=head1 SYNOPSIS
+
+  use Pg::Pcurse::Query1;
+
+=head1 DESCRIPTION
+
+Support SQL queries for Pg::Pcurse
+
+
+=head1 SEE ALSO
+
+Pg::Pcurse, pcurse(1)
+
+=head1 AUTHOR
+
+Ioannis Tambouras, E<lt>ioannis@cpan.org<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2008 by Ioannis Tambouras
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms of GPLv3
+
+
+=cut
