@@ -1,7 +1,7 @@
 # Copyright (C) 2008 Ioannis Tambouras <ioannis@cpan.org>. All rights reserved.
 # LICENSE:  GPLv3, eead licensing terms at  http://www.fsf.org .
 package Pg::Pcurse::Query3;
-use 5.008008;
+use v5.8;
 use DBIx::Abstract;
 use Carp::Assert;
 use base 'Exporter';
@@ -78,18 +78,18 @@ sub proc_of {
         my $dh = dbconnect ( $o, form_dsn($o, $database ) ) or return;
 
         (my $st = $dh->{dbh}->prepare( <<""))->execute( $oid, 'pg_proc', $oid);
-	         select proname  , nspname , pg_get_userbyid(proowner) as owner,
+	         SELECT proname  , nspname , pg_get_userbyid(proowner) as owner,
                         lanname  , procost , prorows       , proisagg ,
                         prosecdef, proisstrict , proretset , provolatile , 
                         pronargs , prorettype::regtype     , proallargtypes, 
                         proargtypes ,
                         prosrc   , proargmodes , proargnames, probin ,
                         proacl   , proconfig   ,
-		        pg_catalog.obj_description( ?, ? )  as desc
-		from pg_proc p 
-                     join pg_namespace n on (pronamespace= n.oid)
-		     join pg_language  l on (prolang = l.oid)
-                where p.oid = ?
+		        pg_catalog.obj_description( ?, ? )  AS desc
+		FROM pg_proc P 
+                     join pg_namespace N on (pronamespace= N.oid)
+		     join pg_language  L on (prolang = L.oid)
+                WHERE p.oid = ?
 
         my $h = $st->fetchrow_hashref  ;
 	$h->{proargtypes} = types2text( $o, $h->{proargtypes} );
@@ -282,13 +282,13 @@ sub tables_of_db {
 	my ($o, $database ) = @_;
 	my $dh  = dbconnect ( $o, form_dsn($o,$database)  ) or return;
         my $h   = $dh->{dbh}->selectall_arrayref( <<"");
-		select  nspname||'.'||relname, age( relfrozenxid )
-		from pg_class c
-			 join pg_namespace n on ( n.oid= c.relnamespace)
-		where relkind = 'r'
+		SELECT  nspname||'.'||relname, age( relfrozenxid )
+		FROM pg_class c
+			 join pg_namespace N on ( N.oid= C.relnamespace)
+		WHERE relkind = 'r'
 			and nspname not like 'pg_%'
 			and nspname not like 'information_schema'
-		order by 1
+		ORDER BY 1
 
         [ map { sprintf '%-40s  %5.3f', ${$_}[0], ${$_}[1]/1_000_000 } @$h ]
 }
@@ -379,11 +379,11 @@ sub dict {
         my $dh  = dbconnect ( $o, form_dsn($o, $database ) ) or return;
         $schema = $dh->quote( $schema );
         my $h   = $dh->{dbh}->selectall_arrayref( <<"" );
-	 	select dictname,  pg_get_userbyid( dictowner), tmplname
-		from      pg_ts_dict     d
-	             join pg_namespace   n  on (dictnamespace=n.oid)
-	             join pg_ts_template t  on (d.dicttemplate=t.oid)
-	        where nspname = $schema
+	 	SELECT dictname,  pg_get_userbyid( dictowner), tmplname
+		FROM      pg_ts_dict     D
+	             join pg_namespace   D  on (dictnamespace=D.oid)
+	             join pg_ts_template D  on (D.dicttemplate=D.oid)
+	        WHERE nspname = $schema
 
 	[ map { sprintf('%-20s %-10s         %-10s', @{$_}[0..2] )} 
 	     @$h
@@ -393,7 +393,7 @@ sub dict {
 sub indexdef {
         my ($o, $database, $oid )= @_;
         my $dh  = dbconnect ( $o, form_dsn($o, $database ) ) or return;
-	my $h   = $dh->select_one_to_hashref( "pg_get_indexdef($oid) as def");
+	my $h   = $dh->select_one_to_hashref( "pg_get_indexdef($oid) AS def");
         [ '','', Curses::Widgets::textwrap( $h->{def} , 50) ]
 }
 sub statisticsof {
@@ -592,7 +592,7 @@ sub pgbuff_all {
         my $dh = dbconnect ( $o, form_dsn($o, $database ) ) or return;
 
         my $h = $dh->select_one_to_hashref(<<"");
-	   user in (select rolname from pg_roles where rolsuper) as super
+	   user in (select rolname from pg_roles where rolsuper) AS super
 
         return [ q(Must be in a "super" role to view buffer data.) ]
                      unless $h->{super}; 
@@ -604,12 +604,12 @@ sub pgbuff_all {
 	if ($db_of_func eq $database) {
                 return ['Not Implemented']  if $mode =~ /^not_cached$/io;
 		(my $st = $dh->{dbh}->prepare(<<""))->execute;
-			select D.datname, B.relfilenode as oid, count(1)
-			from   pg_buffercache B
+			SELECT D.datname, B.relfilenode AS oid, count(1)
+			FROM   pg_buffercache B
 			       join pg_database D  on ( D.oid=B.reldatabase)
 			--where  B.relfilenode::regclass::text !~ '^pg_'
-			group  by datname, B.relfilenode --, relpages
-			order  by 1 , count desc
+			GROUP  BY datname, B.relfilenode --, relpages
+			ORDER  BY 1 , count DESC
 
 		my (%o2n, $tcount);
 		$o2n{$database} = oid2name_per_db($o, $database);
@@ -639,7 +639,7 @@ sub pgbufpages {
         my $dh = dbconnect ( $o, form_dsn($o, $database ) ) or return;
 
         my $h = $dh->select_one_to_hashref(<<"");
-	   user in (select rolname from pg_roles where rolsuper) as super
+	   user in (select rolname from pg_roles where rolsuper) AS super
 
         return [ q(Must be in a "super" role to view buffer data.) ]
                      unless $h->{super}; 
@@ -651,11 +651,11 @@ sub pgbufpages {
 	if ($db_of_func eq $database) {
                 return ['Not Applicable']  if $mode =~ /^not_cached$/io;
 		(my $st = $dh->{dbh}->prepare(<<""))->execute;
-		select  datname , relfilenode as oid , 
-                        relblocknumber as bn, bytes
-		from pg_freespacemap_pages F
+		SELECT  datname , relfilenode AS oid , 
+                        relblocknumber AS bn, bytes
+		FROM pg_freespacemap_pages F
 			join pg_database D on (D.oid = F.reldatabase)
-		where bytes is not null
+		WHERE bytes is not NULL
 
 		my (%o2n, $tcount);
 		$o2n{$database} = oid2name_per_db($o, $database);
@@ -774,8 +774,8 @@ sub tables_vacuum {
         $schema = $dh->quote($schema);
         my $h  = $dh->{dbh}->selectall_arrayref(<<"");
         select relname,
-                greatest( last_vacuum,  last_autovacuum ) as vacuum,
-                greatest( last_analyze, last_autoanalyze) as analyze
+                greatest( last_vacuum,  last_autovacuum ) AS vacuum,
+                greatest( last_analyze, last_autoanalyze) AS analyze
         from pg_stat_all_tables
         where schemaname=$schema
         order by 2, 3, 1
@@ -787,4 +787,33 @@ sub tables_vacuum {
 
 
 1;
-__END__
+=head1 NAME
+
+Pg::Pcurse::Query3  - Support SQL queries for Pg::Pcurse
+
+=head1 SYNOPSIS
+
+  use Pg::Pcurse::Query3;
+
+=head1 DESCRIPTION
+
+Support SQL queries for Pg::Pcurse
+
+
+=head1 SEE ALSO
+
+Pg::Pcurse, pcurse(1)
+
+=head1 AUTHOR
+
+Ioannis Tambouras, E<lt>ioannis@cpan.org<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2008 by Ioannis Tambouras
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms of GPLv3
+
+
+=cut
